/*--------------------------------------------------------------------
 *    The GMTPLUS-system:	%W%	%G%
 *
 *  Based on...
 *    The GMT-system:	@(#)uwmtogmtplus.c	2.6  6/25/95
 *
 *--------------------------------------------------------------------*/
/*
 * gmt2gmtplus reads a gmt format data file and creates
 * the standard gmtplus file {*.gmtd, *.gmth}.
 *
 * This program converts data only, and does not do any additional
 * calculations (such as corrected meters or mag anomaly).
 *
 * GMTPlus 03/10/95 jcm
 * David Sandwell 6/25/95 
 *
 */
#include <gmt.h>
struct GMT_REC {        /* Format of *.gmt file records */
        int time;
        int lat;
        int lon;
        short int gmt[3];
};
#include "gmtplus_mgg.h"
#include <time.h>

#define NODATA -32000

struct GMT_REC irecord;
struct GMT_PLUS_REC record;
struct COL_N col;

int main (int argc, char *argv[])
{
	int i, rec, n_records, leg_year;
	int t_flag = FALSE;
	char file[80], agency[10] = "", legfname[80];
	FILE *fp = NULL, *fpo, *hpo;
    int count;

	if (argc != 2) {
		fprintf (stderr, "usage: gmt2gmtplus file.gmt \n");
		exit (-1);
	}
		
/*  read and interpret the command line */

	fp = fopen (argv[1], "r");
	sscanf(argv[1],"%[^.].gmt",legfname);

/* open output data file */

	sprintf (file, "%s.gmtd\0", legfname);

	if ((fpo = fopen (file, "w")) == NULL) {
		fprintf (stderr, "Could not create data file %s\n", file);
		exit (-1);
	}


/* Read first record of file containing start-year, n_records and info */

	if (fread((char *)(&leg_year), 4, 1, fp) != 1) {
		fprintf(stderr,"gmt2gmtplus: Error while reading first year\n");
		exit(-1);
	}
	if (fread((char *)(&n_records), 4, 1, fp) != 1) {
		fprintf(stderr,"gmt2gmtplus: Error while reading no of records\n");
		exit(-1);
	}
	if (fread(agency, 10, 1, fp) != 1) {
		fprintf(stderr,"gmt2gmtplus: Error while reading info-header\n");
		exit(-1);
	}

	agency[10] = '\0';
	printf ("%d %d %s\n", leg_year, n_records, agency);

/*  set  gmtplus index */

	read_gmt_master_index();
	col.tsec = 0;
	col.lat = 1;
	col.lon = 2;
	col.graw = -1;
	col.gfaa = 6;
	col.twtt = -1;
	col.tcor = 8;
	col.mtot = -1;
	col.manm = 10;
	col.mflt = -1;
	col.user_long[0] = -1;
	col.user_long[1] = -1;
	col.user_long[2] = -1;
	col.user_long[3] = -1;
	col.user_long[4] = -1;
	col.user_long[5] = -1;
	col.user_short[0] = -1;
	col.user_short[1] = -1;
	col.user_short[2] = -1;
	col.user_short[3] = -1;
	col.user_short[4] = -1;
	col.user_short[5] = -1;
	col.user_short[6] = -1;
	col.user_short[7] = -1;

/* write first record of data file */
	
	write_first_gmt_datarec(fpo, &col);
	
	for (rec = 0; rec < n_records; rec++) {
		if (fread ((char *)(&irecord), 18, 1, fp) != 1) {
			fprintf (stderr,"gmt2gmtplus: Error reading data record no %d\n",rec);
			exit(-1);
		}
		for (i=0;i<6;i++)
			record.ldata[i] = 0;
		for (i=0;i<8;i++)
			record.sdata[i] = 0;

/*  load the old gmt into the new gmt */

                record.ldata[col.tsec] = irecord.time;
                record.ldata[col.lat] = irecord.lat;
                record.ldata[col.lon] = irecord.lon;
                record.sdata[col.gfaa-6] = irecord.gmt[0];
                record.sdata[col.manm-6] = irecord.gmt[1];
                record.sdata[col.tcor-6] = irecord.gmt[2];
		if (fwrite((char *)(&record), 40, 1, fpo) != 1) {
			fprintf(stderr,"gmt2gmtplus: Error writing data record no %d\n",rec);
			exit(-1);
		}
	}

/*  close the files */
	if (fp != stdin) fclose (fp);
	fclose(fpo);
	
	sprintf (file, "%s.gmth\0", legfname);
	if ((hpo = fopen (file, "w")) == NULL) {
		fprintf (stderr, "Could not create header file %s\n", file);
		exit (-1);
	}
	sprintf (file, "%s.gmtd\0", legfname);

	write_gmt_header(hpo, &col, leg_year, n_records, agency, legfname, file);

	fclose(hpo);
		
	exit(0);
}


