/*--------------------------------------------------------------------
 *    The GMTPLUS-system:	@(#)gmtplus2dat.c	1.1	3/24/95
 *
 *  Based on...
 *	The GMT-system:	@(#)gmt2dat.c	2.3  7/22/93
 *
 *	Copyright (c) 1991 by P. Wessel and W. H. F. Smith
 *	See README file for copying and redistribution conditions.
 *--------------------------------------------------------------------*/
/*
 * gmt2dat will read a gmt file and create an ascii listing
 * of all the information stored in the *.gmt file. The ASCII
 * file can then be edited manually. Run dat2gmt to put the
 * edited file into *.gmt binary format.
 *
 * Author:	Paul Wessel
 * Date:	8-FEB-1988
 *
 *
 * GMTPlus version 03/10/95 jcm
 * Modifications made for gmtplus database system.
 *
 */

#include <stdio.h>
#include <math.h>

#include <gmt.h>

#include "gmtplus_mgg.h"

#define NODATA -32000

struct GMT_PLUS_REC *record;
struct COL_N col;

int
main (int argc, char *argv[])
{
	int rec, n_records, leg_year, yr, mo, dy, hr, mi, sc;
	double lat, lon;
	char agency[10] = "", cruise[80] = "";
	FILE *fp, *hp;
	struct GMT *gmt;
	char gmtfile[80], gmtheader[80];
	int i;

	gmtpath_init();

	if (argc != 2) {
		fprintf(stderr, "usage: gmtplus2dat gmtfile > asciifile\n");
		exit (-1);
	}
	if (gmtpath_func (gmtfile, gmtheader, argv[1])) {
		fprintf (stderr, "gmtplus2dat : Cannot find leg %s\n", argv[1]);
		exit(-1);
	}
	if ((fp = fopen (gmtfile,"r")) == NULL) {
		fprintf (stderr,"gmtplus2dat: Could not open %s\n", gmtfile);
		exit(-1);
	}
	if ((hp = fopen (gmtheader,"r")) == NULL) {
		fprintf (stderr,"gmtplus2dat: Could not open %s\n", gmtheader);
		fclose(fp);
		exit(-1);
	}

	
	/* Read first record of file containing start-year, n_records and info */

	read_gmt_master_index();
	read_gmt_header(hp, &col, &leg_year, &n_records, agency, cruise);
	/* 03/23/95 jcm include pedigree lines??? */
	read_first_gmt_datarec(fp, &col);
	
	record = (struct GMT_PLUS_REC *) GMT_memory ((char *)NULL, n_records, sizeof (struct GMT_PLUS_REC), "gmtplus2dat");
	
	gmt = gmt_init (leg_year);
	
	printf ("year=%d nrec=%d agency=%s cruise=%s\n", leg_year, n_records, strlen(agency) ? agency : "(none)", cruise);
	
	for (rec = 0; rec < n_records; rec++) {
		if (fread ((char *)(&record[rec]), 40, 1, fp) != 1) {
			fprintf (stderr,"gmtplus2dat: Error reading data record no %d\n",rec);
			exit(-1);
		}
	}
	fclose(fp);


	/* print column headers */
	printf("tsec                  lat        lon   ");
	for (i=0;i<6;i++) {
	  if (first_record.ldata[i] != TSEC 
	      && first_record.ldata[i] != LAT
	      && first_record.ldata[i] != LON) {
	    if (first_record.ldata[i] != -1)
	      printf("%10s",gmt_column_name[first_record.ldata[i]]); 
	    else {
	      printf("%10s", "not_used");
	    }
	  }
	}
	for (i=0;i<8;i++) {
	  if (first_record.sdata[i] != TSEC 
	      && first_record.sdata[i] != LAT
	      && first_record.sdata[i] != LON) {
	    if (first_record.sdata[i] != -1)
	      printf("%10s",gmt_column_name[first_record.sdata[i]]);
	    else {
	      printf("%10s", "not_used");
	    }
	  }
	}
	printf("\n");

	/* print each data record */
	for (rec = 0; rec < n_records; rec++) {
		gmt_date (record[rec].ldata[col.tsec], &yr, &mo, &dy, &hr, &mi, &sc, gmt);
		lat = (double) record[rec].ldata[col.lat] * 0.000001;
		lon = (double) record[rec].ldata[col.lon] * 0.000001;
		printf("%d/%.2d/%.2d/%.2d:%.2d:%.2d%10.5lf%10.5lf", yr, mo, dy, hr, mi, sc, lat, lon);
		for (i=0;i<6;i++) {
			if (first_record.ldata[i] != TSEC 
				&& first_record.ldata[i] != LAT
				&& first_record.ldata[i] != LON) {
				(record[rec].ldata[i] == NODATA) ? printf("       NaN") : printf("%10d",record[rec].ldata[i]);
			}
		}
		for (i=0;i<8;i++) {
			if (first_record.sdata[i] != TSEC 
				&& first_record.sdata[i] != LAT
				&& first_record.sdata[i] != LON) {
                if (first_record.sdata[i] == MTOT) {
				   (record[rec].sdata[i] == NODATA) 
                                    ? printf("       NaN") : printf("%10d",record[rec].sdata[i] + 50000);
                } else {
				   (record[rec].sdata[i] == NODATA) ? printf("       NaN") : printf("%10d",record[rec].sdata[i]);
                }
			}
		}
		printf("\n");

	}
	
	free ((char *)gmt);
	free ((char *)record);
	
	exit (0);
}
